@@ -3,10 +3,12 @@ from enum import Enum
 class LoginMode(Enum):
     credentials = 0
     oauth = 1
+    none = 2
 
 class FileTransferMode(Enum):
     active = 0
     passive = 1
+    passiveWithLink = 2
 
 class FileTransferArchive(Enum):
     none = 0
